@@ -12,14 +12,13 @@
 #
 ##############################################################################
 """
-$Id: tests.py 106612 2009-12-16 02:10:27Z srichter $
+$Id: tests.py 116038 2010-08-30 19:10:45Z srichter $
 """
 __docformat__ = "reStructuredText"
 import logging
 import os
 import unittest
-from zope.testing import doctest
-from zope.testing.doctestunit import DocFileSuite
+import doctest
 
 class TestingHandler(logging.Handler):
 
@@ -39,7 +38,7 @@ def tearDown(test):
 
 def test_suite():
     return unittest.TestSuite((
-        DocFileSuite(
+        doctest.DocFileSuite(
             'README.txt',
             globs={'cmd': do_cmd},
             setUp=setUp, tearDown=tearDown,
